@@ -11,11 +11,10 @@
   }
 
   nstep <- c(seq(step, to=mag, by=step))
-  sfac  <- sqrt(pca$L[pc])*nstep
-  
-  scor  <- function(x,u,m) { return(x*u+m) }
-  plus  <- sapply(c(sfac), scor, u=pca$U[,pc], m=pca$mean)
-  minus <- sapply(c(-sfac), scor, u=pca$U[,pc], m=pca$mean)
+  zcoor  <- cbind(sqrt(pca$L[pc])) %*% nstep
+
+  plus  <- apply(zcoor, 2, pca.z2xyz, pca)
+  minus <- apply( (-(zcoor)), 2, pca.z2xyz, pca)
   coor  <- t(cbind(pca$mean,
                    plus, plus[,rev(1:ncol(plus))],
                    pca$mean,
