@@ -1,5 +1,9 @@
 "read.all" <-
-function(aln, pdb.path="./", pdbext=".pdb", sel=NULL) {
+function(aln, pdb.path="", pdbext="", sel=NULL, ...) {
+
+  ## Usage:
+  ## sel <- c("N", "CA", "C", "O", "CB", "*G", "*D",  "*E", "*Z")
+  ## pdbs.all <- read.all(aln, sel=sel)
 
   if(pdb.path=="") {
     files  <- file.path(paste(aln$id, pdbext,sep=""))
@@ -39,7 +43,7 @@ function(aln, pdb.path="./", pdbext=".pdb", sel=NULL) {
       ##coords.all
       ##
     } else {
-      pdb <- read.pdb( files[i], verbose=FALSE )
+      pdb <- read.pdb( files[i], verbose=FALSE, ... )
       pdbseq  <- aa321(pdb$atom[pdb$calpha,"resid"])
       aliseq  <- toupper(aln$ali[i,])
       tomatch <- gsub("X","[A-Z]",aliseq[aliseq!="-"])
