@@ -36,7 +36,7 @@ function(aln, pdb.path="", pdbext="", ...) {
       pdb <- read.pdb( files[i], verbose=FALSE, ... )
       pdbseq  <- aa321(pdb$atom[pdb$calpha,"resid"])
       aliseq  <- toupper(aln$ali[i,])
-      tomatch <- gsub("X","[A-Z]",aliseq[aliseq!="-"])
+      tomatch <- gsub("X","[A-Z]",aliseq[!is.gap(aliseq)])
       
       ##-- Search for ali residues (1:15) in pdb
       start.num <- regexpr(pattern = paste(c(na.omit(tomatch[1:15])),collapse=""),
@@ -47,7 +47,7 @@ function(aln, pdb.path="", pdbext="", ...) {
 
       ##-- Numeric vec, 'nseq', for mapping aln to pdb
       nseq <- rep(NA,length(aliseq))
-      ali.res.ind <- which(aliseq != "-")
+      ali.res.ind <- which(!is.gap(aliseq))
       if( length(ali.res.ind) > length(pdbseq) ) {
         warning(paste(aln$id[i],
          ": sequence has more residues than PDB has Calpha's"))
